Crate mpc_macros

Crate mpc_macros 

Async-MPC Macros

This crate provides procedural macros for the async-mpc library.

Macros

define_task
Generates async-mpc task implementations with automatic dependency management.
dump_protocol_tags
Macro to dump the current state of the protocol tag registry at compile time (for debugging)
new_protocol
Macro to ensure protocol tag uniqueness at compile time. This macro generates a unique tag for a given protocol name, and checks against a registry to prevent collisions. If a collision is detected, it finds the next available tag.

Attribute Macros

public
Procedural macro to expose a private member function for given cfg tags.

Derive Macros

GateMethods
Derives Gate::map_labels and Gate::for_each_label
HasTweakableHasher
Procedural macro to automatically implement the HasTweakableHasher trait for a struct.
Party
Procedural macro to automatically implement the Party trait for a struct.
Peer
Procedural macro to automatically implement the Peer trait for a struct.
Probabilistic
Procedural macro to automatically implement the Probabilistic trait for a struct.
Scribe
Procedural macro to automatically implement the Scribe trait for a struct.
TaskGetters
Derives try_get_*_task functions for enum variants containing task types.