new_protocol

Macro new_protocol 

new_protocol!() { /* proc-macro */ }
Macro to ensure protocol tag uniqueness at compile time. This macro generates a unique tag for a given protocol name, and checks against a registry to prevent collisions. If a collision is detected, it finds the next available tag.